@@ -24,6 +24,7 @@ class notificator(QObject):
             self.UIContainer[BottomLeft] = dict()
             self.UIContainer[BottomCenter] = dict()
             self.UIContainer[BottomRight] = dict()
+            self.importFonts()
             self.__instanced = True
 
     def critical(self,Title:str,Message:str,Parent:QMainWindow=None,Align:Align=TopRight,progressBar=False,duracion=15,onclick=None,ondoubleclick=None,onrightclick=None):
@@ -115,4 +116,21 @@ class notificator(QObject):
     def close(self):
         self.destroy()
 
+    def importFonts(self):
+        from resources import *
+        from PyQt5.QtGui import QFontDatabase
+        """ Import all roboto fonts to be used at application """
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Black.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-BlackItalic.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Bold.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-BoldItalic.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Italic.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Light.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-LightItalic.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Medium.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-MediumItalic.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Regular.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-Thin.ttf")
+        QFontDatabase.addApplicationFont(":/source/fonts/Roboto-ThinItalic.ttf")
+
 
